#!/bin/bash

# Declare input
DEVICE_TYPE=$1
BRANCH=$2
VERSION="3.3.2"

export SCRIPT=$(readlink -f "$0")
export SCRIPT_PATH=$(dirname "$SCRIPT")
export SRC_DIR=${SCRIPT_PATH}/../..

# *********************************************************************
# Function: print_help
# 	- Print: Help
# *********************************************************************
print_help ()
{	
	# Print
	echo -e ""
	echo -e "Syntax: test_OpenSSL_mkv128_encrypt.sh <arch> <version>"
	echo -e "<arch>: Arch of device hardware. Only support"
	echo -e "	linux-arm32 	Linux ARM 32 bit"
	echo -e "	linux-arm64 	Linux ARM 64 bit"
	echo -e "	linux-ppc64 	Linux PowerPC 64 bit"
	echo -e "	linux-x86_64 	Linux AMD 64 bit"
	echo -e "	windows-mingw32	Windows AMD 32 bit"
	echo -e "	windows-mingw64	Windows AMD 64 bit"
	echo -e "	linux-kirkwood	OpenWRT Kirkwood"
	echo -e "<branch>: Source branch of software. Only support"
	echo -e "	bml 		Branch for BML"
	echo -e "	mmds 		Branch for MMDS"
	echo -e "	tmc 		Branch for TMC"
	echo -e "	net 		Branch for NET"
	echo -e ""
	echo -e "Example:"
	echo -e "- Example: test_OpenSSL_mkv128_encrypt.sh linux-arm32 bml"
	echo -e "- Example: test_OpenSSL_mkv128_encrypt.sh \"linux-ppc64\" \"mmds\""
	echo -e ""
}



# Validate input
if [[ -z $DEVICE_TYPE || -z $BRANCH ]]; then
	echo -e "You must enter enough information. Cannot execute the command."
	print_help
	exit
fi

# Variables
item_exists="0"
names=("linux-arm32" \
"linux-arm64" \
"linux-ppc64" \
"linux-x86_64" \
"windows-mingw32" \
"windows-mingw64" \
"linux-kirkwood")
for item in ${names[@]}; do
	if [[ "${item}" = "${DEVICE_TYPE}" ]]; then
    	item_exists="1"
	fi
done
if [[ "$item_exists" == "0" ]]; then
	echo -e "The device type is invalid. Cannot execute the command."
	echo -e "Device type must be in supported list."
	print_help
	exit
fi

item_exists="0"
names=("bml" \
"mmds" \
"tmc" \
"net")
for item in ${names[@]}; do
	if [[ "${item}" = "${BRANCH}" ]]; then
    	item_exists="1"
	fi
done
if [[ "$item_exists" == "0" ]]; then
	echo -e "The software branch is invalid. Cannot execute the command."
	echo -e "Software branch must be in supported list."
	print_help
	exit
fi

# Output path
export PREFIX=/opt/vgisc/usr
export THIRD_PARTY_PREFIX=/opt/third_party
export OUTPUT_DIR=output/${APP_NAME}-${DEVICE_TYPE}-${VERSION}-${BUILD_TYPE}
export RELEASE_DIR=$SRC_DIR/../../release/${BRANCH}/release/${DEVICE_TYPE}
export ZIP_DIR=$SRC_DIR/../../release/${BRANCH}/zip
export STATIC_DIR=$SRC_DIR/../../release/${BRANCH}/static/${DEVICE_TYPE}
export DYNAMIC_DIR=$SRC_DIR/../../release/${BRANCH}/dynamic/${DEVICE_TYPE}
export BOOT_DIR=$SRC_DIR/../../release/${BRANCH}/rootfs/boot
export INSTALLERS_DIR=$SRC_DIR/../../release/${BRANCH}/installers/${DEVICE}_installer-${VERSION}
export INSTALLERS_DST=${DEVICE}_installer-${BRANCH}

export OPENSSL_BIN="${STATIC_DIR}/opt/vgisc/usr/bin/openssl"
export PKI_DIR="/vgisc/6t/workspace/PKI/test"

echo ""
echo "========================================================================"
echo "Starting TLSv1.3 client with OpenSSL 3.x..."
echo "========================================================================"

${OPENSSL_BIN} s_client -connect localhost:8003 \
	-key ${PKI_DIR}/vpn1.vgisc.com.key \
	-cert ${PKI_DIR}/vpn1.vgisc.com.crt \
	-CAfile ${PKI_DIR}/root-ca.crt \
	-CApath /etc/ssl/certs/ \
	-debug -keylogfile /var/tmp/tls_client1.txt -msg -state -tlsextdebug \
	--trace -security_debug -security_debug_verbose \
	-ciphersuites "TLS_MKC3_256_GCM_SHA256"

echo ""
echo "===> Done."