#!/bin/bash

# Declare input
DEVICE_TYPE=$1
BRANCH=$2
VERSION="3.3.2"

export SCRIPT=$(readlink -f "$0")
export SCRIPT_PATH=$(dirname "$SCRIPT")
export SRC_DIR=${SCRIPT_PATH}/../..

export LD_LIBRARY_PATH="/vgisc/6t/CT129/Dev/MMDS/release/mmds/release/linux-x86_64/opt/vgisc/usr/lib:$LD_LIBRARY_PATH"

# *********************************************************************
# Function: print_help
# 	- Print: Help
# *********************************************************************
print_help ()
{	
	# Print
	echo -e ""
	echo -e "Syntax: test_OpenSSL_mkv128_encrypt.sh <arch> <version>"
	echo -e "<arch>: Arch of device hardware. Only support"
	echo -e "	linux-arm32 	Linux ARM 32 bit"
	echo -e "	linux-arm64 	Linux ARM 64 bit"
	echo -e "	linux-ppc64 	Linux PowerPC 64 bit"
	echo -e "	linux-x86_64 	Linux AMD 64 bit"
	echo -e "	windows-mingw32	Windows AMD 32 bit"
	echo -e "	windows-mingw64	Windows AMD 64 bit"
	echo -e "	linux-kirkwood	OpenWRT Kirkwood"
	echo -e "<branch>: Source branch of software. Only support"
	echo -e "	bml 		Branch for BML"
	echo -e "	mmds 		Branch for MMDS"
	echo -e "	tmc 		Branch for TMC"
	echo -e "	tmc 		Branch for NET"
	echo -e ""
	echo -e "Example:"
	echo -e "- Example: test_OpenSSL_mkv128_encrypt.sh linux-arm32 bml"
	echo -e "- Example: test_OpenSSL_mkv128_encrypt.sh \"linux-ppc64\" \"mmds\""
	echo -e ""
}



# Validate input
if [[ -z $DEVICE_TYPE || -z $BRANCH ]]; then
	echo -e "You must enter enough information. Cannot execute the command."
	print_help
	exit
fi

# Variables
item_exists="0"
names=("linux-arm32" \
"linux-arm64" \
"linux-ppc64" \
"linux-x86_64" \
"windows-mingw32" \
"windows-mingw64" \
"linux-kirkwood")
for item in ${names[@]}; do
	if [[ "${item}" = "${DEVICE_TYPE}" ]]; then
    	item_exists="1"
	fi
done
if [[ "$item_exists" == "0" ]]; then
	echo -e "The device type is invalid. Cannot execute the command."
	echo -e "Device type must be in supported list."
	print_help
	exit
fi

item_exists="0"
names=("bml" \
"mmds" \
"tmc" \
"net")
for item in ${names[@]}; do
	if [[ "${item}" = "${BRANCH}" ]]; then
    	item_exists="1"
	fi
done
if [[ "$item_exists" == "0" ]]; then
	echo -e "The software branch is invalid. Cannot execute the command."
	echo -e "Software branch must be in supported list."
	print_help
	exit
fi

# Output path
export PREFIX=/opt/vgisc/usr
export THIRD_PARTY_PREFIX=/opt/third_party
export OUTPUT_DIR=output/${APP_NAME}-${DEVICE_TYPE}-${VERSION}-${BUILD_TYPE}
export RELEASE_DIR=$SRC_DIR/../../release/${BRANCH}/release/${DEVICE_TYPE}
export ZIP_DIR=$SRC_DIR/../../release/${BRANCH}/zip
export STATIC_DIR=$SRC_DIR/../../release/${BRANCH}/static/${DEVICE_TYPE}
export DYNAMIC_DIR=$SRC_DIR/../../release/${BRANCH}/dynamic/${DEVICE_TYPE}
export BOOT_DIR=$SRC_DIR/../../release/${BRANCH}/rootfs/boot
export INSTALLERS_DIR=$SRC_DIR/../../release/${BRANCH}/installers/${DEVICE}_installer-${VERSION}
export INSTALLERS_DST=${DEVICE}_installer-${BRANCH}

export OPENSSL_BIN="${STATIC_DIR}/opt/vgisc/usr/bin/openssl"
export TEST_DIR=${SRC_DIR}/scripts/test/mkv128

echo ""
echo "========================================================================"
echo "mkv128 encryption/decryption..."
echo "========================================================================"

mkdir -p ${TEST_DIR}/
rm -rf ${TEST_DIR}/*

cp -rf ${SRC_DIR}/LICENSE.txt ${TEST_DIR}/LICENSE.txt

echo ""
echo "mkv128-128 encryption/decryption..."

${OPENSSL_BIN} enc -mkv128-128-ecb -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ecb.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-ecb -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-ecb.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ecb.dec -pass pass:12345678 

${OPENSSL_BIN} enc -mkv128-128-cbc -v -debug -p -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cbc.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-cbc -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-cbc.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cbc.dec -pass pass:12345678 

${OPENSSL_BIN} enc -mkv128-128-ofb -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ofb.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-ofb -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-ofb.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ofb.dec -pass pass:12345678  

${OPENSSL_BIN} enc -mkv128-128-ctr -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ctr.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-ctr -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-ctr.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-ctr.dec -pass pass:12345678  

${OPENSSL_BIN} enc -mkv128-128-cfb -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-cfb -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb.dec -pass pass:12345678   

${OPENSSL_BIN} enc -mkv128-128-cfb1 -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb1.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-cfb1 -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb1.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb1.dec -pass pass:12345678   

${OPENSSL_BIN} enc -mkv128-128-cfb8 -pbkdf2 -a -in ${TEST_DIR}/LICENSE.txt -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb8.enc -pass pass:12345678
#${OPENSSL_BIN} enc -mkv128-128-cfb8 -pbkdf2 -d -a -in ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb8.enc -out ${TEST_DIR}/LICENSE.txt.mkv128-128-cfb8.dec -pass pass:12345678


echo ""
echo "mkv128 encryption/decryption result in ${TEST_DIR}/"
ls -la ${TEST_DIR}/ | grep mkv128

echo ""
echo "===> Done."
